API docs for “spamfighter.core.message.test.test_message.MessageTestCase”

# Class s.c.m.t.t.MessageTestCase(unittest.TestCase):

Part of spamfighter.core.message.test.test_message View Source View In Hierarchy

Тест на `spamfighter.core.message.message.Message`.

Method | setUp | Undocumented
Method | testInterface | Undocumented
Method | testGet | Undocumented

def setUp(self): (source)
Undocumented
def testInterface(self): (source)
Undocumented
def testGet(self): (source)
Undocumented